==> coda-6.9.5.tar.gz: coda-6.9.5/coda-src/asr/resolver_parser.h <==

/* A Bison parser, made by GNU Bison 2.4.1.  */

/* Skeleton interface for Bison's Yacc-like parsers in C
   
      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     COMMA = 258,
     OBJECT_NAME = 259,
     DEPENDENCY_NAME = 260,
     NEW_LINE = 261,
     COLON = 262,
     SEMI_COLON = 263,
     COMMAND_NAME = 264,
     WHITESPACE = 265,
     ARG_NAME = 266,
     ALL = 267,
     INTEGER = 268,
     REPLICA_COUNT = 269,
     BLANK_LINE = 270
   };
#endif
/* Tokens.  */
#define COMMA 258
#define OBJECT_NAME 259
#define DEPENDENCY_NAME 260
#define NEW_LINE 261
#define COLON 262
#define SEMI_COLON 263
#define COMMAND_NAME 264
#define WHITESPACE 265
#define ARG_NAME 266
#define ALL 267
#define INTEGER 268
#define REPLICA_COUNT 269
#define BLANK_LINE 270




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef int YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif

extern YYSTYPE yylval;

==> coda-8.1.6.tar.gz: coda-8.1.6/coda-src/asr/resolver_parser.h <==
/* A Bison parser, made by GNU Bison 3.3.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Undocumented macros, especially those whose name start with YY_,
   are private implementation details.  Do not rely on them.  */

#ifndef YY_YY_RESOLVER_PARSER_H_INCLUDED
# define YY_YY_RESOLVER_PARSER_H_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int yydebug;
#endif

/* Token type.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    COMMA = 258,
    OBJECT_NAME = 259,
    DEPENDENCY_NAME = 260,
    NEW_LINE = 261,
    COLON = 262,
    SEMI_COLON = 263,
    COMMAND_NAME = 264,
    WHITESPACE = 265,
    ARG_NAME = 266,
    ALL = 267,
    INTEGER = 268,
    REPLICA_COUNT = 269,
    BLANK_LINE = 270
  };
#endif
/* Tokens.  */
#define COMMA 258
#define OBJECT_NAME 259
#define DEPENDENCY_NAME 260
#define NEW_LINE 261
#define COLON 262
#define SEMI_COLON 263
#define COMMAND_NAME 264
#define WHITESPACE 265
#define ARG_NAME 266
#define ALL 267
#define INTEGER 268
#define REPLICA_COUNT 269
#define BLANK_LINE 270

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef int YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif


extern YYSTYPE yylval;

int yyparse (void);

#endif /* !YY_YY_RESOLVER_PARSER_H_INCLUDED  */
